==> PlanetExplorer%20Hive%20SDK%20v4%2025.8.0.zip: PlanetExplorer Hive SDK v4 25.8.0/PlanetExplore 1.3.0/Assets/Hive_SDK_v4/Editor/PostProcess/iOS/HivePostProcessFileIOS.cs <==
using System.Collections;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEditor;
using hive;

public class HivePostProcessFileIOS {
    private string fileName;
    private string filePath;

    public HivePostProcessFileIOS() {
        fileName = "HivePostProcessSettingIOS.txt";
        filePath = "Assets/Hive_SDK_v4/Editor/PostProcess/iOS/" + fileName;
    }

    public void writePostProcessSetting(Dictionary<string, string> setting) {
        cleanFile(filePath);

        var jsonObj = new JSONObject(setting);
        var jsonString = jsonObj.ToString();
        
        var writer = new StreamWriter(filePath, true);
        writer.WriteLine(jsonString);
        writer.Close();
        
        #if UNITY_EDITOR
        AssetDatabase.ImportAsset(filePath);
        #endif 
    }

    public Dictionary<string, string> readPostProcessSetting() {
        if (!isFileExist(filePath)) {
            return null;
        }
        
        var reader = new StreamReader(filePath); 
        var jsonString = reader.ReadToEnd();
        reader.Close();

        var jsonObj = new JSONObject(jsonString);
        var dictionary = jsonObj.ToDictionary();

        return dictionary;
    }

    private bool isFileExist(string filePath) {
        if (File.Exists(filePath)) {
            return true;
        }
        return false;
    }

    private void cleanFile(string filePath) {
        if (!isFileExist(filePath)) {
            return;
        }
        File.WriteAllText(filePath, string.Empty);
    }
}

==> PlanetExplorer%20Hive%20SDK%20v4%2026.1.2.zip: PlanetExplorer Hive SDK v4 26.1.2/PlanetExplore 1.4.0/Assets/Hive_SDK_v4/Editor/PostProcess/iOS/HivePostProcessFileIOS.cs <==
using System.Collections;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEditor;
using hive;

public class HivePostProcessFileIOS {
    private string fileName;
    private string filePath;

    public HivePostProcessFileIOS() {
        fileName = "HivePostProcessSettingIOS.txt";
        filePath = "Assets/Hive_SDK_v4/Editor/PostProcess/iOS/" + fileName;
    }

    public void writePostProcessSetting(Dictionary<string, string> setting) {
        cleanFile(filePath);

        var jsonObj = new hive.JSONObject(setting);
        var jsonString = jsonObj.ToString();
        
        var writer = new StreamWriter(filePath, true);
        writer.WriteLine(jsonString);
        writer.Close();
        
        #if UNITY_EDITOR
        AssetDatabase.ImportAsset(filePath);
        #endif 
    }

    public Dictionary<string, string> readPostProcessSetting() {
        if (!isFileExist(filePath)) {
            return null;
        }
        
        var reader = new StreamReader(filePath); 
        var jsonString = reader.ReadToEnd();
        reader.Close();

        var jsonObj = new hive.JSONObject(jsonString);
        var dictionary = jsonObj.ToDictionary();

        return dictionary;
    }

    private bool isFileExist(string filePath) {
        if (File.Exists(filePath)) {
            return true;
        }
        return false;
    }

    private void cleanFile(string filePath) {
        if (!isFileExist(filePath)) {
            return;
        }
        File.WriteAllText(filePath, string.Empty);
    }
}
